==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPRouteAttr.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const TRIPRouteAttr_cxx_Version = 
"$Id: TRIPRouteAttr.cxx,v 1.2 2000/11/03 01:02:10 surendra Exp $";

#include "TRIPRouteAttr.hxx"
#include "TRIPUtil.hxx"

TRIPRouteAttr::TRIPRouteAttr(u_int8_t aFlg, TRIPAttrTypeFlag type)
{
    if(aFlg & TRIP_FLG_LINK_STATE)
    {
        assert(0);
    }
    _hdr = new TRIPAttrHeader(aFlg, type);
};


TRIPRouteAttr::TRIPRouteAttr(u_int8_t aFlg, 
              TRIPAttrTypeFlag type, const TRIPId& id, u_int32_t seqNum)
{
    assert(aFlg & TRIP_FLG_LINK_STATE);
    _hdr = new TRIPLinkStateAttrHeader(aFlg, type, id, seqNum);
}

///
TRIPRouteAttr::TRIPRouteAttr(const char* buf) throw (TRIPBadDataException&)
{
    _hdr = new TRIPAttrHeader(buf);
}

void 
TRIPRouteAttr::writeData(int id) const throw(VNetworkException&)
{
    _hdr->writeData(id);
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPRouteAttr.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const TRIPRouteAttr_cxx_Version = 
"$Id: TRIPRouteAttr.cxx,v 1.7 2001/01/20 02:35:11 sprajpat Exp $";

#include "TRIPRouteAttr.hxx"
#include "TRIPUtil.hxx"

static const int ATTR_MIN_LENGTH=4;

TRIPRouteAttr::TRIPRouteAttr(u_int8_t aFlg, TRIPAttrType type)
{
    if((aFlg != 0 ) && !(aFlg & TRIP_FLG_ALL))
    {
        assert(0);
    }
    assert(!(aFlg & TRIP_FLG_LINK_STATE));
    _hdr = new TRIPAttrHeader(aFlg, type);
    setLength(0);
};


TRIPRouteAttr::TRIPRouteAttr(u_int8_t aFlg, 
              TRIPAttrType type, const TRIPId& id, u_int32_t seqNum)
{
    if((aFlg != 0 ) && !(aFlg & TRIP_FLG_ALL))
    {
        assert(0);
    }
    _hdr = new TRIPLinkStateAttrHeader(aFlg, type, id, seqNum);
    setLength(0);
}

///
TRIPRouteAttr::TRIPRouteAttr(const char* buf) throw (TRIPBadDataException&)
{
    assert(buf);
    TRIPAttrHeader::TripAttrHeaderData hData;
    memcpy(&hData, buf, ATTR_MIN_LENGTH);
    if(hData._flag & TRIP_FLG_LINK_STATE)
    {
        _hdr = new TRIPLinkStateAttrHeader(buf);
    }
    else
    {
        _hdr = new TRIPAttrHeader(buf);
    }
}

void 
TRIPRouteAttr::writeData(int id) const throw(VNetworkException&)
{
    _hdr->writeData(id);
}
